@@ -14,6 +14,7 @@
 #   You should have received a copy of the GNU General Public License
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 import inspect, linecache, os, sys, shlex, traceback, types
+import pyficache
 from repr import Repr
 
 from import_relative import import_relative, get_srcdir
@@ -108,7 +109,7 @@ def resolve_name(obj, command_name):
         return None
     return
 
-def print_source_line(msg_nocr, lineno, line, event_str=None):
+def print_source_line(msg, lineno, line, event_str=None):
     """Print out a source line of text , e.g. the second
     line in:
         (/tmp.py:2):  <module>
@@ -121,7 +122,7 @@ def print_source_line(msg_nocr, lineno, line, event_str=None):
 
     # We don't use the filename normally. ipython and other applications
     # however might.
-    return msg_nocr('%s %d %s' % (event_str, lineno, line))
+    return msg('%s %d %s' % (event_str, lineno, line))
 
 def print_source_location_info(print_fn, filename, lineno, fn_name=None):
     """Print out a source location , e.g. the first line in
@@ -168,20 +169,19 @@ def print_location(proc_obj):
         fn_name = frame.f_code.co_name
         print_source_location_info(intf_obj.msg, filename, lineno, fn_name)
 
-        if '__loader__' in proc_obj.curframe.f_globals:
-            l = proc_obj.curframe.f_globals['__loader__']
-            intf_obj.msg(str(l))
-            pass
-        if 2 == linecache.getline.func_code.co_argcount:
-            line = linecache.getline(filename, lineno)
-        else:
+        opts = {
+            'reload_on_change' : proc_obj.settings('reload'),
+            'output'           : proc_obj.settings('highlight')
+            }
+        line = pyficache.getline(filename, lineno, opts)
+        if not line:
             line = linecache.getline(filename, lineno, 
                                      proc_obj.curframe.f_globals)
             pass
 
         if line and len(line.strip()) != 0:
             if proc_obj.event:
-                print_source_line(intf_obj.msg_nocr, lineno, line, 
+                print_source_line(intf_obj.msg, lineno, line, 
                                   proc_obj.event2short[proc_obj.event])
             pass
         if '<string>' != filename:
@@ -214,7 +214,10 @@ class CommandProcessor(Mbase_proc.Processor):
         self.event2short['brkpt']  = 'xx'
 
         self.cmd_instances    = self._populate_commands()
+        self.cmd_name         = ''     # command name before alias or
+                                       # macro resolution
         self.cmd_queue        = []     # Queued debugger commands
+        self.current_command  = ''     # Current command getting run
         self.debug_nest       = 1
         self.display_mgr      = Mdisplay.DisplayMgr()
         self.intf             = core_obj.debugger.intf
@@ -313,10 +316,16 @@ class CommandProcessor(Mbase_proc.Processor):
         self.event     = event
         self.event_arg = event_arg
 
+        filename = frame.f_code.co_filename
+        lineno   = frame.f_lineno
+        line     = linecache.getline(filename, lineno, frame.f_globals)
+        if not line:
+            opts = {'output': 'plain',
+                    'reload_on_change': self.settings('reload'),
+                    'strip_nl': False}
+            line = pyficache.getline(filename, lineno, opts)
+        self.current_source_text = line
         if self.settings('skip') is not None:
-            filename = frame.f_code.co_filename
-            lineno   = frame.f_lineno
-            line     = linecache.getline(filename, lineno)
             if Mbytecode.is_def_stmt(line, frame):
                 return True
             if Mbytecode.is_class_def(line, frame):
@@ -617,37 +626,40 @@ class CommandProcessor(Mbase_proc.Processor):
     def process_command(self):
         # process command
         if len(self.cmd_queue) > 0:
-            last_command = self.cmd_queue[0].strip()
+            current_command = self.cmd_queue[0].strip()
             del self.cmd_queue[0]
         else:
-            last_command = self.intf[-1].read_command(self.prompt_str).strip()
-            if '' == last_command and self.intf[-1].interactive: 
-                last_command = self.last_command
+            current_command = (
+                self.intf[-1].read_command(self.prompt_str).strip())
+            if '' == current_command and self.intf[-1].interactive: 
+                current_command = self.last_command
                 pass
             pass
         # Look for comments
-        if '' == last_command:
+        if '' == current_command:
             if self.intf[-1].interactive:
                 self.errmsg("No previous command registered, " + 
                             "so this is a no-op.")
                 pass
             return False
-        if last_command is None or last_command[0] == '#':
+        if current_command is None or current_command[0] == '#':
             return False
         try:
-            args_list = arg_split(last_command)
+            args_list = arg_split(current_command)
         except:
             self.errmsg("bad parse %s"< sys.exc_info()[0])
             return False
 
         for args in args_list:
             if len(args):
-                cmd_name = resolve_name(self, args[0])
+                self.cmd_name = args[0]
+                cmd_name = resolve_name(self, self.cmd_name)
                 if cmd_name:
-                    self.last_command = last_command
+                    self.last_command = current_command
                     cmd_obj = self.name2cmd[cmd_name]
                     if self.ok_for_running(cmd_obj, cmd_name, len(args)-1):
-                        try: 
+                        try:
+                            self.current_command = current_command
                             result = cmd_obj.run(args)
                             if result: return result
                         except (Mexcept.DebuggerQuit, 
@@ -661,9 +673,9 @@ class CommandProcessor(Mbase_proc.Processor):
                         pass
                     pass
                 elif not self.settings('autoeval'):
-                    self.undefined_cmd(last_command)
+                    self.undefined_cmd(current_command)
                 else:
-                    self.exec_line(last_command)
+                    self.exec_line(current_command)
                     pass
                 pass
             pass
@@ -841,7 +853,9 @@ if __name__=='__main__':
     print resolve_name(cmdproc, 'q')
     print resolve_name(cmdproc, 'info')
     print resolve_name(cmdproc, 'i')
-    print_source_line(sys.stdout.write, 100, 'source_line_test.py')
+    # print '-' * 10
+    # print_source_line(sys.stdout.write, 100, 'source_line_test.py')
+    # print '-' * 10
     cmdproc.frame = sys._getframe()
     cmdproc.setup()
     print
