@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-#   Copyright (C) 2009, 2010 Rocky Bernstein
+#   Copyright (C) 2009, 2010, 2012 Rocky Bernstein
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@ and storing it as a list of known debugger commands.
 """
 
 NotImplementedMessage = "This method must be overriden in a subclass"
+from pygments.console import colorize
 
 # Note: don't end classname with Command (capital C) since cmdproc
 # will think this a command name like QuitCommand 
@@ -96,6 +97,11 @@ class DebuggerSubcommand:
         """
         raise NotImplementedError, NotImplementedMessage
 
+    def section(self, message, opts={}):
+        if 'terminal' == self.settings['highlight']:
+            message = colorize('bold', message)
+            pass
+        self.msg(message)
     pass
 
 from import_relative import import_relative
